fx.async.fiber

Fiber abstraction, supervisor tree, and concurrent execution runners for fx.

Fiber abstraction, supervisor tree, and concurrent execution runners for fx.
raw docstring

add-finalizer!clj/s

(add-finalizer! fiber finalizer)

Registers a cleanup finalizer thunk or effect to be executed when the fiber completes or is interrupted.

Registers a cleanup finalizer thunk or effect to be executed when the fiber completes or is interrupted.
raw docstring

add-interrupt-handler!clj/s

(add-interrupt-handler! fiber handler-fn)

Registers a callback to be invoked immediately when the fiber is interrupted.

Registers a callback to be invoked immediately when the fiber is interrupted.
raw docstring

default-thread-poolclj


default-virtual-executorclj


interrupt-fiber!clj/s

(interrupt-fiber! fiber)
(interrupt-fiber! fiber reason)

Atomically interrupts fiber and cascades cancellation to all active child fibers.

Atomically interrupts `fiber` and cascades cancellation to all active child fibers.
raw docstring

join-fiber!clj/s

(join-fiber! fiber)
(join-fiber! fiber timeout-ms timeout-val)

Awaits completion of fiber and returns its outcome (or propagates failure / throws).

Awaits completion of `fiber` and returns its outcome (or propagates failure / throws).
raw docstring

make-fiberclj/s

(make-fiber)
(make-fiber parent-fiber)

Constructs a new unstarted or initial Fiber instance.

Constructs a new unstarted or initial Fiber instance.
raw docstring

register-child!clj/s

(register-child! parent-fiber child-fiber)

Registers child-fiber into parent-fiber's children supervisor set.

Registers `child-fiber` into `parent-fiber`'s children supervisor set.
raw docstring

run-async-chan!clj/s

(run-async-chan! effect)
(run-async-chan! effect context)

Executes effect in a background fiber and puts the final outcome onto a core.async channel. Closes the channel upon completion. Returns the output channel.

Executes `effect` in a background fiber and puts the final outcome onto a core.async channel.
Closes the channel upon completion. Returns the output channel.
raw docstring

run-fiber!clj/s

(run-fiber! effect)
(run-fiber! effect context)

Executes effect asynchronously in a dedicated lightweight Fiber, returning the IFiber instance. Binds :fiber in the evaluation context and coordinates parent-child supervisor hierarchy.

Executes `effect` asynchronously in a dedicated lightweight Fiber, returning the `IFiber` instance.
Binds `:fiber` in the evaluation context and coordinates parent-child supervisor hierarchy.
raw docstring

unregister-child!clj/s

(unregister-child! parent-fiber child-fiber)

Removes child-fiber from parent-fiber's children supervisor set.

Removes `child-fiber` from `parent-fiber`'s children supervisor set.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries